"""
* SPDX-License-Identifier: GPL-3.0-or-later
*
* Author: Tommy McGee (tommy.mcgee@opensource.wdc.com)
*
* Copyright (c) 2022 Western Digital Corporation or its affiliates.
*
* This module is used to provide kernel configuration information
* to determine if Zone Block Support is available
"""
import os
import re
import platform
import gzip
import io

def check_kernel_configs():
    """ Scan through the kernel configs to determine the
        configuration status, of the Zone Block requirements.
        This uses regex patterns to get exact matches.
        Additionally for proc systems the function uses
        gzip and io modules to read and output the config
        information
    """
    config_sets = ("CONFIG_SCSI_DEBUG", "CONFIG_BLK_DEV_NVME",
                   "CONFIG_BLK_DEV_ZONED", "CONFIG_BLK_DEV_NULL_BLK",
                   "CONFIG_ZONEFS_FS", "CONFIG_F2FS_FS",
                   "CONFIG_BTRFS_FS", "CONFIG_DM_FLAKEY",
                   "CONFIG_MD_LINEAR", "CONFIG_DM_ZONED",
                   "CONFIG_DM_CRYPT")
    for i_case in config_sets:
        pattern_module = r'%s' % i_case + "=m"
        pattern_yes = r'%s' % i_case + "=y"
        pattern_no = r'%s' % i_case + "=n"
        file_path_check = r'/proc/config.gz'
        flag = os.path.isfile(file_path_check)
        if flag:
            file_name = '/proc/config.gz'
            gz_open_file = gzip.open(file_name, 'rb')
            open_file = io.TextIOWrapper(gz_open_file, encoding='utf-8')
        else:
            long_uname = platform.uname()
            printed_kernel_version = long_uname.release.strip('.#')
            file_name = '/boot/config-' + printed_kernel_version
            open_file = open(file_name)
        for _, line in enumerate(open_file):
            line = line.rstrip()
            for match in re.finditer(pattern_module, line):
                print("-- " + match.group() + " - Loadable Module")
            for match in re.finditer(pattern_yes, line):
                print("-- " + match.group() + " - Enabled")
            for match in re.finditer(pattern_no, line):
                print("-- " + match.group() + " - Disabled")

def check_kernel_module():
    """Scan through specific modules for zone arguments
       using modinfo, the function uses a grep shell command
       to look for specified text, if exist the system is a yes
       for ZBD.
    """
    cmd_scsi_debug = os.popen('modinfo scsi_debug | grep zbc')
    cmd_null_blk = os.popen('modinfo null_blk | grep zoned:')
    modules_to_scan = (cmd_null_blk, cmd_scsi_debug)
    for m_case in modules_to_scan:
        read_text = str(m_case.read()) # Read text from the case
        check_result = len(read_text) # Length of the string
        if check_result == 0:
            print("-- No")
        else:
            print("-- Yes")
