"""
* SPDX-License-Identifier: GPL-3.0-or-later
*
* Author: Tommy McGee (tommy.mcgee@opensource.wdc.com)
*
* Copyright (c) 2022 Western Digital Corporation or its affiliates.
*
* This module is used to provide OS and Kernel general information
"""
import ast
import re
import sys
import platform

def check_distro():
    """
            Check the distro to use os-release for pretty name
            a) Checks to see if the file exits in either location
            b) When found strip the whitespace skip the commented lines
            c) Match the pattern that is being asked in the pretty name
               using regex
            d) if no matched are found show the unmatched lines.
    """
    try:
        file_name = '/etc/os-release'
        open_file = open(file_name)
    except FileNotFoundError:
        file_name = '/usr/lib/os-release'
        open_file = open(file_name)
    for each_line, line in enumerate(open_file):
        line = line.rstrip()
        if not line or line.startswith('#'):
            continue
        if txt_pattern := re.match(r'([A-Z][A-Z_0-9]+)=(.*)', line):
            name, val = txt_pattern.groups()
            if val and val[0] in '"\'':
                val = ast.literal_eval(val)
            yield name, val
        else:
            print(f'{file_name}:{each_line + 1}: bad line {line!r}',
                  file=sys.stderr)

def kernel_information():
    """ Kernel Version information formatted, and determine if the
        system kernel is supported.
    """
    characters = 4
    uname = platform.uname()
    kernel_version = uname.release.strip('.#')
    display_kernel = (kernel_version[:characters])
    numeric_value = float(display_kernel)
    min_numeric_value = float('4.10')
    strdisplay = '-- Kernel Version: ' + display_kernel
    if numeric_value >= min_numeric_value:
        print(
            strdisplay + " >>> Kernel supports zoned block devices"
        )
    else:
        print(
            strdisplay + " >>> Kernel does not support zoned block devices"
        )
